@@ -2,8 +2,8 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
@@ -11,13 +11,14 @@
 import time
 import pyutilib.misc
 import pyomo.opt
-import pyomo.util
+import pyomo.common
 from pyomo.core import TransformationFactory, Var, Set
 
 
-class BILEVEL_Solver2(pyomo.opt.OptSolver):
 
-    pyomo.util.plugin.alias('bilevel_blp_global', doc='Global solver for continuous bilevel linear problems')
+@pyomo.opt.SolverFactory.register('bilevel_blp_global',
+    doc='Global solver for continuous bilevel linear problems')
+class BILEVEL_Solver2(pyomo.opt.OptSolver):
 
     def __init__(self, **kwds):
         kwds['type'] = 'bilevel_blp_global'
@@ -130,4 +131,3 @@ class BILEVEL_Solver2(pyomo.opt.OptSolver):
         #
         self._instance = None
         return results
-
