@@ -3,14 +3,15 @@ from __future__ import division
 
 from math import fabs
 
+from pyomo.common.errors import InfeasibleConstraintException
+from pyomo.contrib.fbbt.fbbt import fbbt
 from pyomo.contrib.gdpopt.data_class import SubproblemResult
 from pyomo.contrib.gdpopt.util import (SuppressInfeasibleWarning,
                                        is_feasible)
 from pyomo.core import Constraint, TransformationFactory, minimize, value, Objective
 from pyomo.core.expr import current as EXPR
 from pyomo.core.kernel.component_set import ComponentSet
-from pyomo.gdp import Disjunct
-from pyomo.opt import SolverFactory
+from pyomo.opt import SolverFactory, SolverResults
 from pyomo.opt import TerminationCondition as tc
 
 
@@ -28,6 +29,48 @@ def solve_disjunctive_subproblem(mip_result, solve_data, config):
             return solve_global_subproblem(mip_result, solve_data, config)
 
 
+def solve_linear_subproblem(mip_model, solve_data, config):
+    GDPopt = mip_model.GDPopt_utils
+
+    initialize_subproblem(mip_model, solve_data)
+
+    # Callback immediately before solving NLP subproblem
+    config.call_before_subproblem_solve(mip_model, solve_data)
+
+    mip_solver = SolverFactory(config.mip_solver)
+    if not mip_solver.available():
+        raise RuntimeError("MIP solver %s is not available." % config.mip_solver)
+    with SuppressInfeasibleWarning():
+        results = mip_solver.solve(mip_model, **config.mip_solver_args)
+
+    subprob_result = SubproblemResult()
+    subprob_result.feasible = True
+    subprob_result.var_values = list(v.value for v in GDPopt.variable_list)
+    subprob_result.pyomo_results = results
+    subprob_result.dual_values = list(mip_model.dual.get(c, None) for c in GDPopt.constraint_list)
+
+    subprob_terminate_cond = results.solver.termination_condition
+    if subprob_terminate_cond is tc.optimal:
+        pass
+    elif subprob_terminate_cond is tc.infeasible:
+        config.logger.info('MIP subproblem was infeasible.')
+        subprob_result.feasible = False
+    else:
+        raise ValueError(
+            'GDPopt unable to handle MIP subproblem termination '
+            'condition of %s. Results: %s'
+            % (subprob_terminate_cond, results))
+
+    # Call the NLP post-solve callback
+    config.call_after_subproblem_solve(mip_model, solve_data)
+
+    # if feasible, call the NLP post-feasible callback
+    if subprob_result.feasible:
+        config.call_after_subproblem_feasible(mip_model, solve_data)
+
+    return subprob_result
+
+
 def solve_NLP(nlp_model, solve_data, config):
     """Solve the NLP subproblem."""
     config.logger.info(
@@ -42,9 +85,6 @@ def solve_NLP(nlp_model, solve_data, config):
 
     GDPopt = nlp_model.GDPopt_utils
 
-    if config.subproblem_presolve:
-        preprocess_subproblem(nlp_model, config)
-
     initialize_subproblem(nlp_model, solve_data)
 
     # Callback immediately before solving NLP subproblem
@@ -55,7 +95,15 @@ def solve_NLP(nlp_model, solve_data, config):
         raise RuntimeError("NLP solver %s is not available." %
                            config.nlp_solver)
     with SuppressInfeasibleWarning():
-        results = nlp_solver.solve(nlp_model, **config.nlp_solver_args)
+        try:
+            results = nlp_solver.solve(nlp_model, **config.nlp_solver_args)
+        except ValueError as err:
+            if 'Cannot load SolverResults object with bad status: error' in str(err):
+                results = SolverResults()
+                results.solver.termination_condition = tc.error
+                results.solver.message = str(err)
+            else:
+                raise
 
     nlp_result = SubproblemResult()
     nlp_result.feasible = True
@@ -65,15 +113,13 @@ def solve_NLP(nlp_model, solve_data, config):
         nlp_model.dual.get(c, None)
         for c in GDPopt.constraint_list)
 
-    subprob_terminate_cond = results.solver.termination_condition
-    if (subprob_terminate_cond is tc.optimal or
-            subprob_terminate_cond is tc.locallyOptimal or
-            subprob_terminate_cond is tc.feasible):
+    term_cond = results.solver.termination_condition
+    if any(term_cond == cond for cond in (tc.optimal, tc.locallyOptimal, tc.feasible)):
         pass
-    elif subprob_terminate_cond is tc.infeasible:
+    elif term_cond == tc.infeasible:
         config.logger.info('NLP subproblem was infeasible.')
         nlp_result.feasible = False
-    elif subprob_terminate_cond is tc.maxIterations:
+    elif term_cond == tc.maxIterations:
         # TODO try something else? Reinitialize with different initial
         # value?
         config.logger.info(
@@ -84,16 +130,34 @@ def solve_NLP(nlp_model, solve_data, config):
                 'Using potentially suboptimal feasible solution.')
         else:
             nlp_result.feasible = False
-    elif subprob_terminate_cond is tc.internalSolverError:
+    elif term_cond == tc.internalSolverError:
         # Possible that IPOPT had a restoration failure
         config.logger.info(
             "NLP solver had an internal failure: %s" % results.solver.message)
         nlp_result.feasible = False
+    elif (term_cond == tc.other and
+          "Too few degrees of freedom" in str(results.solver.message)):
+        # Possible IPOPT degrees of freedom error
+        config.logger.info(
+            "IPOPT has too few degrees of freedom: %s" %
+            results.solver.message)
+        nlp_result.feasible = False
+    elif term_cond == tc.other:
+        config.logger.info(
+            "NLP solver had a termination condition of 'other': %s" %
+            results.solver.message)
+        nlp_result.feasible = False
+    elif term_cond == tc.error:
+        config.logger.info("NLP solver had a termination condition of 'error': %s" % results.solver.message)
+        nlp_result.feasible = False
+    elif term_cond == tc.maxTimeLimit:
+        config.logger.info("NLP solver ran out of time. Assuming infeasible for now.")
+        nlp_result.feasible = False
     else:
         raise ValueError(
             'GDPopt unable to handle NLP subproblem termination '
             'condition of %s. Results: %s'
-            % (subprob_terminate_cond, results))
+            % (term_cond, results))
 
     # Call the NLP post-solve callback
     config.call_after_subproblem_solve(nlp_model, solve_data)
@@ -113,12 +177,9 @@ def solve_MINLP(model, solve_data, config):
 
     GDPopt = model.GDPopt_utils
 
-    if config.subproblem_presolve:
-        preprocess_subproblem(model, config)
-
     initialize_subproblem(model, solve_data)
 
-    # Callback immediately before solving NLP subproblem
+    # Callback immediately before solving MINLP subproblem
     config.call_before_subproblem_solve(model, solve_data)
 
     minlp_solver = SolverFactory(config.minlp_solver)
@@ -136,15 +197,13 @@ def solve_MINLP(model, solve_data, config):
         model.dual.get(c, None)
         for c in GDPopt.constraint_list)
 
-    subprob_terminate_cond = results.solver.termination_condition
-    if (subprob_terminate_cond is tc.optimal or
-            subprob_terminate_cond is tc.locallyOptimal or
-            subprob_terminate_cond is tc.feasible):
+    term_cond = results.solver.termination_condition
+    if any(term_cond == cond for cond in (tc.optimal, tc.locallyOptimal, tc.feasible)):
         pass
-    elif subprob_terminate_cond is tc.infeasible:
+    elif term_cond == tc.infeasible:
         config.logger.info('MINLP subproblem was infeasible.')
         subprob_result.feasible = False
-    elif subprob_terminate_cond is tc.maxIterations:
+    elif term_cond == tc.maxIterations:
         # TODO try something else? Reinitialize with different initial
         # value?
         config.logger.info(
@@ -155,7 +214,7 @@ def solve_MINLP(model, solve_data, config):
                 'Using potentially suboptimal feasible solution.')
         else:
             subprob_result.feasible = False
-    elif subprob_terminate_cond is tc.intermediateNonInteger:
+    elif term_cond == tc.intermediateNonInteger:
         config.logger.info(
             "MINLP solver could not find feasible integer solution: %s" % results.solver.message)
         subprob_result.feasible = False
@@ -163,7 +222,7 @@ def solve_MINLP(model, solve_data, config):
         raise ValueError(
             'GDPopt unable to handle MINLP subproblem termination '
             'condition of %s. Results: %s'
-            % (subprob_terminate_cond, results))
+            % (term_cond, results))
 
     # Call the subproblem post-solve callback
     config.call_after_subproblem_solve(model, solve_data)
@@ -184,11 +243,15 @@ def detect_unfixed_discrete_vars(model):
             v for v in EXPR.identify_variables(
                 constr.body, include_fixed=False)
             if not v.is_continuous())
+    for obj in model.component_data_objects(Objective, active=True):
+        var_set.update(v for v in EXPR.identify_variables(obj.expr, include_fixed=False)
+                       if not v.is_continuous())
     return var_set
 
 
 def preprocess_subproblem(m, config):
     """Applies preprocessing transformations to the model."""
+    # fbbt(m, integer_tol=config.integer_tolerance)
     xfrm = TransformationFactory
     xfrm('contrib.propagate_eq_var_bounds').apply_to(m)
     xfrm('contrib.detect_fixed_vars').apply_to(
@@ -340,16 +403,28 @@ def solve_local_subproblem(mip_result, solve_data, config):
 
     TransformationFactory('gdp.fix_disjuncts').apply_to(subprob)
 
-    for disj in subprob.component_data_objects(Disjunct, active=True):
-        disj.deactivate()  # TODO this is a HACK for something that isn't happening correctly in fix_disjuncts
+    # for disj in subprob.component_data_objects(Disjunct, active=True):
+    #     disj.deactivate()  # TODO this is a HACK for something that isn't happening correctly in fix_disjuncts
 
-    unfixed_discrete_vars = detect_unfixed_discrete_vars(subprob)
-    if config.force_subproblem_nlp and len(unfixed_discrete_vars) > 0:
-        raise RuntimeError("Unfixed discrete variables found on the NLP subproblem.")
-    elif len(unfixed_discrete_vars) == 0:
-        subprob_result = solve_NLP(subprob, solve_data, config)
+    if config.subproblem_presolve:
+        try:
+            preprocess_subproblem(subprob, config)
+        except InfeasibleConstraintException:
+            return get_infeasible_result_object(
+                subprob, "Preprocessing determined problem to be infeasible.")
+
+    if not any(constr.body.polynomial_degree() not in (1, 0)
+               for constr in subprob.component_data_objects(Constraint, active=True)):
+        subprob_result = solve_linear_subproblem(subprob, solve_data, config)
     else:
-        subprob_result = solve_MINLP(subprob, solve_data, config)
+        unfixed_discrete_vars = detect_unfixed_discrete_vars(subprob)
+        if config.force_subproblem_nlp and len(unfixed_discrete_vars) > 0:
+            raise RuntimeError("Unfixed discrete variables found on the NLP subproblem.")
+        elif len(unfixed_discrete_vars) == 0:
+            subprob_result = solve_NLP(subprob, solve_data, config)
+        else:
+            subprob_result = solve_MINLP(subprob, solve_data, config)
+
     if subprob_result.feasible:  # subproblem is feasible
         update_subproblem_progress_indicators(subprob, solve_data, config)
     return subprob_result
@@ -398,6 +473,14 @@ def solve_global_subproblem(mip_result, solve_data, config):
     TransformationFactory('gdp.fix_disjuncts').apply_to(subprob)
     subprob.dual.deactivate()  # global solvers may not give dual info
 
+    if config.subproblem_presolve:
+        try:
+            preprocess_subproblem(subprob, config)
+        except InfeasibleConstraintException as e:
+            # FBBT found the problem to be infeasible
+            return get_infeasible_result_object(
+                subprob, "Preprocessing determined problem to be infeasible.")
+
     unfixed_discrete_vars = detect_unfixed_discrete_vars(subprob)
     if config.force_subproblem_nlp and len(unfixed_discrete_vars) > 0:
         raise RuntimeError("Unfixed discrete variables found on the NLP subproblem.")
@@ -408,3 +491,14 @@ def solve_global_subproblem(mip_result, solve_data, config):
     if subprob_result.feasible:  # NLP is feasible
         update_subproblem_progress_indicators(subprob, solve_data, config)
     return subprob_result
+
+
+def get_infeasible_result_object(model, message=""):
+    infeas_result = SubproblemResult()
+    infeas_result.feasible = False
+    infeas_result.var_values = list(v.value for v in model.GDPopt_utils.variable_list)
+    infeas_result.pyomo_results = SolverResults()
+    infeas_result.pyomo_results.solver.termination_condition = tc.infeasible
+    infeas_result.pyomo_results.message = message
+    infeas_result.dual_values = list(None for _ in model.GDPopt_utils.constraint_list)
+    return infeas_result
