@@ -36,6 +36,13 @@ import logging
 
 logger = logging.getLogger('pyomo.core')
 
+_legal_unary_functions = {
+    'ceil','floor','exp','log','log10','sqrt',
+    'sin','cos','tan','asin','acos','atan','sinh','cosh','tanh',
+}
+_arc_functions = {'acos','asin','atan'}
+_dnlp_functions = {'ceil','floor','abs'}
+
 #
 # A visitor pattern that creates a string for an expression
 # that is compatible with the GAMS syntax.
@@ -46,6 +53,7 @@ class ToGamsVisitor(EXPR.ExpressionValueVisitor):
         super(ToGamsVisitor, self).__init__()
         self.smap = smap
         self.treechecker = treechecker
+        self.is_discontinuous = False
 
     def visit(self, node, values):
         """ Visit nodes that have been expanded """
@@ -87,6 +95,20 @@ class ToGamsVisitor(EXPR.ExpressionValueVisitor):
                 return "power({0}, {1})".format(tmp[0], tmp[1])
             else:
                 return "{0} ** {1}".format(tmp[0], tmp[1])
+        elif node.__class__ is EXPR.UnaryFunctionExpression:
+            if node.name not in _legal_unary_functions:
+                raise RuntimeError(
+                    "GAMS files cannot represent the unary function %s"
+                    % ( node.name, ))
+            if node.name in _dnlp_functions:
+                self.is_discontinuous = True
+            if node.name in _arc_functions:
+                return "arc{0}({1})".format(node.name[1:], tmp[0])
+            else:
+                return node._to_string(tmp, None, self.smap, True)
+        elif node.__class__ is EXPR.AbsExpression:
+            self.is_discontinuous = True
+            return node._to_string(tmp, None, self.smap, True)
         else:
             return node._to_string(tmp, None, self.smap, True)
 
@@ -146,7 +168,8 @@ def expression_to_string(expr, treechecker, labeler=None, smap=None):
             smap = SymbolMap()
         smap.default_labeler = labeler
     visitor = ToGamsVisitor(smap, treechecker)
-    return visitor.dfs_postorder_stack(expr)
+    expr_str = visitor.dfs_postorder_stack(expr)
+    return expr_str, visitor.is_discontinuous
 
 
 class Categorizer(object):
@@ -391,7 +414,15 @@ class ProblemWriter_gams(AbstractProblemWriter):
                              "I/O options is forbidden")
 
         if symbolic_solver_labels:
-            var_labeler = con_labeler = ShortNameLabeler(63, '_')
+            # Note that the Var and Constraint labelers must use the
+            # same labeler, so that we can correctly detect name
+            # collisions (which can arise when we truncate the labels to
+            # the max allowable length.  GAMS requires all identifiers
+            # to start with a letter.  We will (randomly) choose "s_"
+            # (for 'shortened')
+            var_labeler = con_labeler = ShortNameLabeler(
+                63, prefix='s_', suffix='_', caseInsensitive=True,
+                legalRegex='^[a-zA-Z]')
         elif labeler is None:
             var_labeler = NumericLabeler('x')
             con_labeler = NumericLabeler('c')
@@ -471,6 +502,7 @@ class ProblemWriter_gams(AbstractProblemWriter):
         ConstraintIO = StringIO()
         linear = True
         linear_degree = set([0,1])
+        dnlp = False
 
         # Make sure there are no strange ActiveComponents. The expression
         # walker will handle strange things in constraints later.
@@ -508,11 +540,14 @@ class ProblemWriter_gams(AbstractProblemWriter):
                     linear = False
 
             cName = symbolMap.getSymbol(con, con_labeler)
+            con_body_str, con_discontinuous = expression_to_string(
+                con_body, tc, smap=symbolMap)
+            dnlp |= con_discontinuous
             if con.equality:
                 constraint_names.append('%s' % cName)
                 ConstraintIO.write('%s.. %s =e= %s ;\n' % (
                     constraint_names[-1],
-                    expression_to_string(con_body, tc, smap=symbolMap),
+                    con_body_str,
                     _get_bound(con.upper)
                 ))
             else:
@@ -521,13 +556,13 @@ class ProblemWriter_gams(AbstractProblemWriter):
                     ConstraintIO.write('%s.. %s =l= %s ;\n' % (
                         constraint_names[-1],
                         _get_bound(con.lower),
-                        expression_to_string(con_body, tc, smap=symbolMap)
+                        con_body_str,
                     ))
                 if con.has_ub():
                     constraint_names.append('%s_hi' % cName)
                     ConstraintIO.write('%s.. %s =l= %s ;\n' % (
                         constraint_names[-1],
-                        expression_to_string(con_body, tc, smap=symbolMap),
+                        con_body_str,
                         _get_bound(con.upper)
                     ))
 
@@ -542,11 +577,14 @@ class ProblemWriter_gams(AbstractProblemWriter):
         if linear:
             if obj.expr.polynomial_degree() not in linear_degree:
                 linear = False
+        obj_expr_str, obj_discontinuous = expression_to_string(
+            obj.expr, tc, smap=symbolMap)
+        dnlp |= obj_discontinuous
         oName = symbolMap.getSymbol(obj, con_labeler)
         constraint_names.append(oName)
         ConstraintIO.write('%s.. GAMS_OBJECTIVE =e= %s ;\n' % (
             oName,
-            expression_to_string(obj.expr, tc, smap=symbolMap)
+            obj_expr_str,
         ))
 
         # Categorize the variables that we found
@@ -643,6 +681,8 @@ class ProblemWriter_gams(AbstractProblemWriter):
                 (0 if linear else 1) +
                 (2 if (categorized_vars.binary or categorized_vars.ints)
                  else 0)]
+            if mtype == 'nlp' and dnlp:
+                mtype = 'dnlp'
 
         if solver is not None:
             if mtype.upper() not in valid_solvers[solver.upper()]:
