@@ -2,8 +2,8 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
@@ -19,7 +19,7 @@ import time
 import json
 from six import itervalues, iterkeys, iteritems
 from six.moves import xrange
-from pyomo.util import pyomo_api
+from pyomo.common import pyomo_api
 
 try:
     import yaml
@@ -58,13 +58,14 @@ except:
 memory_data = Options()
 
 import pyutilib.misc
-from pyomo.util.plugin import ExtensionPoint, Plugin, implements
+from pyomo.common.plugin import ExtensionPoint, Plugin, implements
 from pyutilib.misc import Container
 from pyutilib.services import TempfileManager
 
 from pyomo.opt import ProblemFormat
 from pyomo.opt.base import SolverFactory
 from pyomo.opt.parallel import SolverManagerFactory
+from pyomo.dataportal import DataPortal
 from pyomo.core import *
 from pyomo.core.base import TextLabeler
 import pyomo.core.base
@@ -236,9 +237,6 @@ def apply_preprocessing(data, parser=None):
                     return self.fn(**kwds)
             tmp = TMP()
             data.local._usermodel_plugins.append( tmp )
-            #print "HERE", modelapi[key], pyomo.util.plugin.interface_services[modelapi[key]]
-
-    #print "HERE", data.options._usermodel_plugins
 
     if 'pyomo_preprocess' in usermodel_dir:
         if data.options.model.object_name in usermodel_dir:
@@ -565,7 +563,7 @@ def apply_optimizer(data, instance=None):
     solver_mngr_name = None
     if data.options.solvers[0].manager is None:
         solver_mngr_name = 'serial'
-    elif not data.options.solvers[0].manager in SolverManagerFactory.services():
+    elif not data.options.solvers[0].manager in SolverManagerFactory:
         raise ValueError("Unknown solver manager %s"
                          % data.options.solvers[0].manager)
     else:
@@ -809,7 +807,7 @@ def finalize(data, model=None, instance=None, results=None):
     ##gc.collect()
     ##print gc.get_referrers(_tmp)
     ##import pyomo.core.base.plugin
-    ##print pyomo.util.plugin.interface_services[pyomo.core.base.plugin.IPyomoScriptSaveResults]
+    ##print pyomo.common.plugin.interface_services[pyomo.core.base.plugin.IPyomoScriptSaveResults]
     ##print "HERE - usermodel_plugins"
     ##
     if not data.options.runtime.logging == 'quiet':
@@ -1043,5 +1041,3 @@ def get_config_values(filename):
         INPUT.close()
         return val
     raise IOError("ERROR: Unexpected configuration file '%s'" % filename)
-
-
