@@ -11,21 +11,23 @@
 import logging
 import re
 import sys
-import pyutilib.services
+import pyomo.common
 from pyutilib.misc import Bunch
-from pyomo.util.plugin import alias
-from pyomo.core.kernel.numvalue import is_fixed
-from pyomo.repn import generate_canonical_repn, LinearCanonicalRepn, canonical_degree
+from pyutilib.services import TempfileManager
+from pyomo.core.expr.numvalue import is_fixed
+from pyomo.core.expr.numvalue import value
+from pyomo.repn import generate_standard_repn
 from pyomo.solvers.plugins.solvers.direct_solver import DirectSolver
 from pyomo.solvers.plugins.solvers.direct_or_persistent_solver import DirectOrPersistentSolver
-from pyomo.core.kernel.numvalue import value
-import pyomo.core.kernel
+from pyomo.core.kernel.objective import minimize, maximize
 from pyomo.core.kernel.component_set import ComponentSet
 from pyomo.core.kernel.component_map import ComponentMap
 from pyomo.opt.results.results_ import SolverResults
 from pyomo.opt.results.solution import Solution, SolutionStatus
 from pyomo.opt.results.solver import TerminationCondition, SolverStatus
+from pyomo.opt.base import SolverFactory
 from pyomo.core.base.suffix import Suffix
+import pyomo.core.base.var
 
 
 logger = logging.getLogger('pyomo.solvers')
@@ -41,8 +43,8 @@ def _is_numeric(x):
         return False
     return True
 
+@SolverFactory.register('gurobi_direct', doc='Direct python interface to Gurobi')
 class GurobiDirect(DirectSolver):
-    alias('gurobi_direct', doc='Direct python interface to Gurobi')
 
     def __init__(self, **kwds):
         kwds['type'] = 'gurobi_direct'
@@ -163,43 +165,31 @@ class GurobiDirect(DirectSolver):
     def _get_expr_from_pyomo_repn(self, repn, max_degree=2):
         referenced_vars = ComponentSet()
 
-        degree = canonical_degree(repn)
+        degree = repn.polynomial_degree()
         if (degree is None) or (degree > max_degree):
             raise DegreeError('GurobiDirect does not support expressions of degree {0}.'.format(degree))
 
-        if isinstance(repn, LinearCanonicalRepn):
-            if (repn.linear is not None) and (len(repn.linear) > 0):
-                list(map(referenced_vars.add, repn.variables))
-                new_expr = self._gurobipy.LinExpr(repn.linear, [self._pyomo_var_to_solver_var_map[i] for i in repn.variables])
-            else:
-                new_expr = 0
-
-            if repn.constant is not None:
-                new_expr += repn.constant
-
+        if len(repn.linear_vars) > 0:
+            referenced_vars.update(repn.linear_vars)
+            new_expr = self._gurobipy.LinExpr(repn.linear_coefs, [self._pyomo_var_to_solver_var_map[i] for i in repn.linear_vars])
         else:
-            new_expr = 0
-            if 0 in repn:
-                new_expr += repn[0][None]
+            new_expr = 0.0
 
-            if 1 in repn:
-                for ndx, coeff in repn[1].items():
-                    new_expr += coeff * self._pyomo_var_to_solver_var_map[repn[-1][ndx]]
-                    referenced_vars.add(repn[-1][ndx])
+        for i,v in enumerate(repn.quadratic_vars):
+            x,y = v
+            new_expr += repn.quadratic_coefs[i] * self._pyomo_var_to_solver_var_map[x] * self._pyomo_var_to_solver_var_map[y]
+            referenced_vars.add(x)
+            referenced_vars.add(y)
 
-            if 2 in repn:
-                for key, coeff in repn[2].items():
-                    tmp_expr = coeff
-                    for ndx, power in key.items():
-                        referenced_vars.add(repn[-1][ndx])
-                        for i in range(power):
-                            tmp_expr *= self._pyomo_var_to_solver_var_map[repn[-1][ndx]]
-                    new_expr += tmp_expr
+        new_expr += repn.constant
 
         return new_expr, referenced_vars
 
     def _get_expr_from_pyomo_expr(self, expr, max_degree=2):
-        repn = generate_canonical_repn(expr)
+        if max_degree == 2:
+            repn = generate_standard_repn(expr, quadratic=True)
+        else:
+            repn = generate_standard_repn(expr, quadratic=False)
 
         try:
             gurobi_expr, referenced_vars = self._get_expr_from_pyomo_repn(repn, max_degree)
@@ -286,10 +276,10 @@ class GurobiDirect(DirectSolver):
             gurobi_expr, referenced_vars = self._get_expr_from_pyomo_repn(
                 con.canonical_form(),
                 self._max_constraint_degree)
-        elif isinstance(con, LinearCanonicalRepn):
-            gurobi_expr, referenced_vars = self._get_expr_from_pyomo_repn(
-                con,
-                self._max_constraint_degree)
+        #elif isinstance(con, LinearCanonicalRepn):
+        #    gurobi_expr, referenced_vars = self._get_expr_from_pyomo_repn(
+        #        con,
+        #        self._max_constraint_degree)
         else:
             gurobi_expr, referenced_vars = self._get_expr_from_pyomo_expr(
                 con.body,
@@ -397,9 +387,9 @@ class GurobiDirect(DirectSolver):
         if obj.active is False:
             raise ValueError('Cannot add inactive objective to solver.')
 
-        if obj.sense == pyomo.core.kernel.minimize:
+        if obj.sense == minimize:
             sense = self._gurobipy.GRB.MINIMIZE
-        elif obj.sense == pyomo.core.kernel.maximize:
+        elif obj.sense == maximize:
             sense = self._gurobipy.GRB.MAXIMIZE
         else:
             raise ValueError('Objective sense is not recognized: {0}'.format(obj.sense))
@@ -551,9 +541,9 @@ class GurobiDirect(DirectSolver):
         self.results.problem.name = gprob.ModelName
 
         if gprob.ModelSense == 1:
-            self.results.problem.sense = pyomo.core.kernel.minimize
+            self.results.problem.sense = minimize
         elif gprob.ModelSense == -1:
-            self.results.problem.sense = pyomo.core.kernel.maximize
+            self.results.problem.sense = maximize
         else:
             raise RuntimeError('Unrecognized gurobi objective sense: {0}'.format(gprob.ModelSense))
 
@@ -690,7 +680,7 @@ class GurobiDirect(DirectSolver):
 
         # finally, clean any temporary files registered with the temp file
         # manager, created populated *directly* by this plugin.
-        pyutilib.services.TempfileManager.pop(remove=not self._keepfiles)
+        TempfileManager.pop(remove=not self._keepfiles)
 
         return DirectOrPersistentSolver._postsolve(self)
 
