@@ -17,8 +17,17 @@ from pyutilib.services import TempfileManager
 from pyomo.core.expr.numvalue import is_fixed
 from pyomo.core.expr.numvalue import value
 from pyomo.repn import generate_standard_repn
-from pyomo.solvers.plugins.solvers.direct_solver import DirectSolver
-from pyomo.solvers.plugins.solvers.direct_or_persistent_solver import DirectOrPersistentSolver
+from pyomo.solvers.plugins.solvers.direct_solver import \
+    DirectSolver
+from pyomo.solvers.plugins.solvers.direct_or_persistent_solver import \
+    DirectOrPersistentSolver
+from pyomo.core.kernel.conic import (_ConicBase,
+                                     quadratic,
+                                     rotated_quadratic,
+                                     primal_exponential,
+                                     primal_power,
+                                     dual_exponential,
+                                     dual_power)
 from pyomo.core.kernel.objective import minimize, maximize
 from pyomo.core.kernel.component_set import ComponentSet
 from pyomo.core.kernel.component_map import ComponentMap
@@ -55,6 +64,8 @@ class MosekDirect(DirectSolver):
         self._solver_var_to_pyomo_var_map = ComponentMap()
         self._pyomo_con_to_solver_con_map = dict()
         self._solver_con_to_pyomo_con_map = ComponentMap()
+        self._pyomo_cone_to_solver_cone_map = dict()
+        self._solver_cone_to_pyomo_cone_map = ComponentMap()
         self._init()
 
     def _init(self):
@@ -95,6 +106,22 @@ class MosekDirect(DirectSolver):
         self._capabilities.sos1 = False
         self._capabilities.sos2 = False
 
+    @staticmethod
+    def license_is_valid():
+        """
+        Runs a check for a valid Mosek license. Returns False
+        if Mosek fails to run on a trivial test case.
+        """
+        try:
+            import mosek
+        except ImportError:
+            return False
+        try:
+            mosek.Env().Task(0,0).optimize()
+        except mosek.Error:
+            return False
+        return True
+
     def _apply_solver(self):
         if not self._save_results:
             for block in self._pyomo_model.block_data_objects(descend_into=True,
@@ -141,6 +168,58 @@ class MosekDirect(DirectSolver):
         # FIXME: can we get a return code indicating if Mosek had a significant failure?
         return Bunch(rc=None, log=None)
 
+    def _get_cone_data(self, con):
+        # if the cone is not recognized, this function
+        # will return None for cone_type and cone_members
+        cone_type = None
+        cone_param = 0
+        cone_members = None
+        if isinstance(con, quadratic):
+            assert con.has_ub() and \
+                (con.ub == 0) and (not con.has_lb())
+            assert con.check_convexity_conditions(relax=True)
+            cone_type = self._mosek.conetype.quad
+            cone_members = [con.r] + list(con.x)
+        elif isinstance(con, rotated_quadratic):
+            assert con.has_ub() and \
+                (con.ub == 0) and (not con.has_lb())
+            assert con.check_convexity_conditions(relax=True)
+            cone_type = self._mosek.conetype.rquad
+            cone_members = [con.r1, con.r2] + list(con.x)
+        elif self._version >= (9, 0, 0):
+            if isinstance(con, primal_exponential):
+                assert con.has_ub() and \
+                    (con.ub == 0) and (not con.has_lb())
+                assert con.check_convexity_conditions(
+                    relax=False)
+                cone_type = self._mosek.conetype.pexp
+                cone_members = [con.r, con.x1, con.x2]
+            elif isinstance(con, primal_power):
+                assert con.has_ub() and \
+                    (con.ub == 0) and (not con.has_lb())
+                assert con.check_convexity_conditions(
+                    relax=False)
+                cone_type = self._mosek.conetype.ppow
+                cone_param = value(con.alpha)
+                cone_members = [con.r1, con.r2] + list(con.x)
+            elif isinstance(con, dual_exponential):
+                assert con.has_ub() and \
+                    (con.ub == 0) and (not con.has_lb())
+                assert con.check_convexity_conditions(
+                    relax=False)
+                cone_type = self._mosek.conetype.dexp
+                cone_members = [con.r, con.x1, con.x2]
+            elif isinstance(con, dual_power):
+                assert con.has_ub() and \
+                    (con.ub == 0) and (not con.has_lb())
+                assert con.check_convexity_conditions(
+                    relax=False)
+                cone_type = self._mosek.conetype.dpow
+                cone_param = value(con.alpha)
+                cone_members = [con.r1, con.r2] + list(con.x)
+
+        return cone_type, cone_param, cone_members
+
     def _get_expr_from_pyomo_repn(self, repn, max_degree=2):
         referenced_vars = ComponentSet()
 
@@ -216,6 +295,8 @@ class MosekDirect(DirectSolver):
         DirectOrPersistentSolver._set_instance(self, model, kwds)
         self._pyomo_con_to_solver_con_map = dict()
         self._solver_con_to_pyomo_con_map = ComponentMap()
+        self._pyomo_cone_to_solver_cone_map = dict()
+        self._solver_cone_to_pyomo_cone_map = ComponentMap()
         self._pyomo_var_to_solver_var_map = ComponentMap()
         self._solver_var_to_pyomo_var_map = ComponentMap()
         self._whichsol = getattr(
@@ -246,39 +327,73 @@ class MosekDirect(DirectSolver):
 
         conname = self._symbol_map.getSymbol(con, self._labeler)
 
+        mosek_expr = None
+        referenced_vars = None
+        cone_type = None
+        cone_param = 0
+        cone_members = None
         if con._linear_canonical_form:
             mosek_expr, referenced_vars = self._get_expr_from_pyomo_repn(
                 con.canonical_form(),
                 self._max_constraint_degree)
+        elif isinstance(con, _ConicBase):
+            cone_type, cone_param, cone_members = \
+                self._get_cone_data(con)
+            if cone_type is not None:
+                assert cone_members is not None
+                referenced_vars = ComponentSet(cone_members)
+            else:
+                logger.warning("Cone %s was not recognized by Mosek"
+                               % (str(con)))
+                # the cone was not recognized, treat
+                # it like a standard constraint, which
+                # will in all likelihood lead to Mosek
+                # reporting a helpful error message
+                assert mosek_expr is None
+        if (mosek_expr is None) and (cone_type is None):
+            mosek_expr, referenced_vars = \
+                self._get_expr_from_pyomo_expr(
+                    con.body,
+                    self._max_constraint_degree)
 
+        assert referenced_vars is not None
+        if mosek_expr is not None:
+            assert cone_type is None
+            self._solver_model.appendcons(1)
+            con_index = self._solver_model.getnumcon()-1
+            con_type, ub, lb = self.set_con_bounds(con, mosek_expr[2])
+
+            if con.has_lb():
+                if not is_fixed(con.lower):
+                    raise ValueError("Lower bound of constraint {0} "
+                                     "is not constant.".format(con))
+            if con.has_ub():
+                if not is_fixed(con.upper):
+                    raise ValueError("Upper bound of constraint {0} "
+                                     "is not constant.".format(con))
+
+            self._solver_model.putarow(con_index, mosek_expr[1], mosek_expr[0])
+            self._solver_model.putqconk(
+                con_index, mosek_expr[4], mosek_expr[5], mosek_expr[3])
+            self._solver_model.putconbound(con_index, con_type, lb, ub)
+            self._solver_model.putconname(con_index, conname)
+            self._pyomo_con_to_solver_con_map[con] = con_index
+            self._solver_con_to_pyomo_con_map[con_index] = con
         else:
-            mosek_expr, referenced_vars = self._get_expr_from_pyomo_expr(
-                con.body,
-                self._max_constraint_degree)
-        self._solver_model.appendcons(1)
-        con_index = self._solver_model.getnumcon()-1
-        con_type, ub, lb = self.set_con_bounds(con, mosek_expr[2])
-
-        if con.has_lb():
-            if not is_fixed(con.lower):
-                raise ValueError("Lower bound of constraint {0} "
-                                 "is not constant.".format(con))
-        if con.has_ub():
-            if not is_fixed(con.upper):
-                raise ValueError("Upper bound of constraint {0} "
-                                 "is not constant.".format(con))
-
-        self._solver_model.putarow(con_index, mosek_expr[1], mosek_expr[0])
-        self._solver_model.putqconk(
-            con_index, mosek_expr[4], mosek_expr[5], mosek_expr[3])
-        self._solver_model.putconbound(con_index, con_type, lb, ub)
-        self._solver_model.putconname(con_index, conname)
+            assert cone_type is not None
+            members = [self._pyomo_var_to_solver_var_map[v_]
+                       for v_ in cone_members]
+            self._solver_model.appendcone(cone_type,
+                                          cone_param,
+                                          members)
+            cone_index = self._solver_model.getnumcone()-1
+            self._solver_model.putconename(cone_index, conname)
+            self._pyomo_cone_to_solver_cone_map[con] = cone_index
+            self._solver_cone_to_pyomo_cone_map[cone_index] = con
 
         for var in referenced_vars:
             self._referenced_variables[var] += 1
         self._vars_referenced_by_con[con] = referenced_vars
-        self._pyomo_con_to_solver_con_map[con] = con_index
-        self._solver_con_to_pyomo_con_map[con_index] = con
 
     def _mosek_vtype_from_var(self, var):
         """
@@ -388,7 +503,9 @@ class MosekDirect(DirectSolver):
         msk_task = self._solver_model
         msk = self._mosek
 
-        itr_soltypes = [msk.problemtype.qo, msk.problemtype.qcqo]
+        itr_soltypes = [msk.problemtype.qo,
+                        msk.problemtype.qcqo,
+                        msk.problemtype.conic]
 
         if (msk_task.getnumintvar() >= 1):
             self._whichsol = msk.soltype.itg
@@ -679,15 +796,32 @@ class MosekDirect(DirectSolver):
                         con_names.append(msk_task.getconname(con))
                     for name in con_names:
                         soln_constraints[name] = {}
+                    """TODO wrong length, needs to be getnumvars()
+                    mosek_cones = list(range(msk_task.getnumcone()))
+                    cone_names = []
+                    for cone in mosek_cones:
+                        cone_names.append(msk_task.getconename(cone))
+                    for name in cone_names:
+                        soln_constraints[name] = {}
+                    """
 
                 if extract_duals:
-                    vals = [0.0]*msk_task.getnumcon()
-                    msk_task.gety(whichsol, vals)
-                    for val, name in zip(vals, con_names):
-                        soln_constraints[name]["Dual"] = val
+                    ncon = msk_task.getnumcon()
+                    if ncon > 0:
+                        vals = [0.0]*ncon
+                        msk_task.gety(whichsol, vals)
+                        for val, name in zip(vals, con_names):
+                            soln_constraints[name]["Dual"] = val
+                    """TODO: wrong length, needs to be getnumvars()
+                    ncone = msk_task.getnumcone()
+                    if ncone > 0:
+                        vals = [0.0]*ncone
+                        msk_task.getsnx(whichsol, vals)
+                        for val, name in zip(vals, cone_names):
+                            soln_constraints[name]["Dual"] = val
+                    """
 
                 if extract_slacks:
-
                     Ax = [0]*len(mosek_cons)
                     msk_task.getxc(self._whichsol, Ax)
                     for con, name in zip(mosek_cons, con_names):
@@ -770,25 +904,69 @@ class MosekDirect(DirectSolver):
             if ref_vars[var] > 0:
                 rc[var] = val
 
-    def _load_duals(self, cons_to_load=None):
+    def _load_duals(self, objs_to_load=None):
         if not hasattr(self._pyomo_model, 'dual'):
             self._pyomo_model.dual = Suffix(direction=Suffix.IMPORT)
         con_map = self._pyomo_con_to_solver_con_map
         reverse_con_map = self._solver_con_to_pyomo_con_map
+        cone_map = self._pyomo_cone_to_solver_cone_map
+        reverse_cone_map = self._solver_cone_to_pyomo_cone_map
         dual = self._pyomo_model.dual
 
-        if cons_to_load is None:
+        if objs_to_load is None:
+            # constraints
             mosek_cons_to_load = range(self._solver_model.getnumcon())
+            vals = [0.0]*len(mosek_cons_to_load)
+            self._solver_model.gety(self._whichsol, vals)
+            for mosek_con, val in zip(mosek_cons_to_load, vals):
+                pyomo_con = reverse_con_map[mosek_con]
+                dual[pyomo_con] = val
+            """TODO wrong length, needs to be getnumvars()
+            # cones
+            mosek_cones_to_load = range(self._solver_model.getnumcone())
+            vals = [0.0]*len(mosek_cones_to_load)
+            self._solver_model.getsnx(self._whichsol, vals)
+            for mosek_cone, val in zip(mosek_cones_to_load, vals):
+                pyomo_cone = reverse_cone_map[mosek_cone]
+                dual[pyomo_cone] = val
+            """
         else:
-            mosek_cons_to_load = set([con_map[pyomo_con]
-                                      for pyomo_con in cons_to_load])
-
-        vals = [0.0]*self._solver_model.getnumcon()
-        self._solver_model.gety(self._whichsol, vals)
-
-        for mosek_con, val in zip(mosek_cons_to_load, vals):
-            pyomo_con = reverse_con_map[mosek_con]
-            dual[pyomo_con] = val
+            mosek_cons_to_load = []
+            mosek_cones_to_load = []
+            for obj in objs_to_load:
+                if obj in con_map:
+                    mosek_cons_to_load.append(con_map[obj])
+                else:
+                    # assume it is a cone
+                    mosek_cones_to_load.append(cone_map[obj])
+            # constraints
+            mosek_cons_first = min(mosek_cons_to_load)
+            mosek_cons_last = max(mosek_cons_to_load)
+            vals = [0.0]*(mosek_cons_last - mosek_cons_first + 1)
+            self._solver_model.getyslice(self._whichsol,
+                                         mosek_cons_first,
+                                         mosek_cons_last,
+                                         vals)
+            for mosek_con in mosek_cons_to_load:
+                slice_index = mosek_con - mosek_cons_first
+                val = vals[slice_index]
+                pyomo_con = reverse_con_map[mosek_con]
+                dual[pyomo_con] = val
+            """TODO wrong length, needs to be getnumvars()
+            # cones
+            mosek_cones_first = min(mosek_cones_to_load)
+            mosek_cones_last = max(mosek_cones_to_load)
+            vals = [0.0]*(mosek_cones_last - mosek_cones_first + 1)
+            self._solver_model.getsnxslice(self._whichsol,
+                                           mosek_cones_first,
+                                           mosek_cones_last,
+                                           vals)
+            for mosek_cone in mosek_cones_to_load:
+                slice_index = mosek_cone - mosek_cones_first
+                val = vals[slice_index]
+                pyomo_cone = reverse_cone_map[mosek_cone]
+                dual[pyomo_cone] = val
+            """
 
     def _load_slacks(self, cons_to_load=None):
         if not hasattr(self._pyomo_model, 'slack'):
